@@ -81,13 +81,15 @@ impl<'a, T: Aabb, S: Sorter> TreeBuilder<'a, T, S> {
             T: Send,
             T::Num: Send,
         {
-            if vistr.get_bots().len() <= num_seq_fallback {
-                vistr.recurse_seq(buffer);
-                splitter
-            } else {
-                let NodeBuildResult { node, rest } = vistr.build_and_next();
+            let NodeBuildResult { node, rest } = vistr.build_and_next();
 
-                if let Some([left, right]) = rest {
+            if let Some([left, right]) = rest {
+                if node.get_num_elem() <= num_seq_fallback {
+                    buffer.push(node.finish());
+                    left.recurse_seq(buffer);
+                    right.recurse_seq(buffer);
+                    splitter
+                } else {
                     let (s1, s2) = splitter.div();
 
                     let (s1, (mut a, s2)) = rayon::join(
@@ -104,10 +106,10 @@ impl<'a, T: Aabb, S: Sorter> TreeBuilder<'a, T, S> {
 
                     buffer.append(&mut a);
                     s1.add(s2)
-                } else {
-                    buffer.push(node.finish());
-                    splitter
                 }
+            } else {
+                buffer.push(node.finish());
+                splitter
             }
         }
         let TreeBuilder {
